## v0.4.0a1 (2024-05-01)

### Fix

- Update license format

## v0.3.0 (2024-05-01)

### Fix

- Update github actions versions
- Merge branch 'main' of github.com:kaeus-sgarcia/kframe
- Merge branch 'main' of github.com:kaeus-sgarcia/kframe
- Fix development, qa, and main branches CI/CD
- Merge branch 'main' of github.com:kaeus-sgarcia/kframe

## v0.2.2 (2024-04-30)

### Fix

- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD

## v0.2.1 (2024-04-30)

### Fix

- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD

## v0.2.0 (2024-04-30)

### Feat

- Initial project structure and cicd action

### Fix

- Fix development, qa, and main branches CI/CD
- Merge branch 'development' of github.com:kaeus-sgarcia/kframe into development
- Fix development, qa, and main branches CI/CD
- Merge branch 'development' of github.com:kaeus-sgarcia/kframe into development
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Fix development, qa, and main branches CI/CD
- Merge branch 'development' of github.com:kaeus-sgarcia/kframe into development
- Fix CI/CD for quality brach
- Merge branch 'development' of github.com:kaeus-sgarcia/kframe into development
- Fix development, qa, and main branches CI/CD
- Fix development brack CI
- Fix cicd for development and quality branches
- Fix cicd for development branch

## v0.1.0 (2024-04-30)

### Feat

- First commit
